Home
last modified time | relevance | path

Searched refs:__obj (Results 1 – 9 of 9) sorted by relevance

/freebsd/contrib/llvm-project/libcxx/include/__pstl/internal/
H A Dunseq_backend_simd.h
/freebsd/contrib/llvm-project/libcxx/include/__stop_token/
H A Dintrusive_shared_ptr.h111 _LIBCPP_HIDE_FROM_ABI static void __increment_ref_count(_Tp& __obj) { in __increment_ref_count()
112 __get_atomic_ref_count(__obj).fetch_add(1, std::memory_order_relaxed); in __increment_ref_count()
115 _LIBCPP_HIDE_FROM_ABI static void __decrement_ref_count(_Tp& __obj) { in __decrement_ref_count()
116 if (__get_atomic_ref_count(__obj).fetch_sub(1, std::memory_order_acq_rel) == 1) { in __decrement_ref_count()
117 delete std::addressof(__obj); in __decrement_ref_count()
121 _LIBCPP_HIDE_FROM_ABI static decltype(auto) __get_atomic_ref_count(_Tp& __obj) { in decltype()
122 using __ret_type = decltype(__intrusive_shared_ptr_traits<_Tp>::__get_atomic_ref_count(__obj)); in decltype()
125 return __intrusive_shared_ptr_traits<_Tp>::__get_atomic_ref_count(__obj); in decltype()
/freebsd/share/mk/
H A Dbsd.dep.mk263 .for __obj in ${DEPENDOBJS:O:u}
267 .if ${__obj:M*/*}
269 _meta_obj= ${.OBJDIR:C,/,_,g}_${__obj:C,/,_,g}.meta
271 _meta_obj= ${__obj:C,/,_,g}.meta
274 _meta_obj= ${__obj}.meta
276 _dep_obj= ${DEPENDFILE}.${__obj:${DEPEND_FILTER}}
290 .if !target(${__obj})
291 ${__obj}: ${OBJS_DEPEND_GUESS}
293 ${__obj}: ${OBJS_DEPEND_GUESS.${__obj}}
H A Dbsd.clang-analyze.mk80 .for __obj in ${CLANG_ANALYZE_OBJS}
81 ${__obj}: ${OBJS_DEPEND_GUESS}
82 ${__obj}: ${OBJS_DEPEND_GUESS.${__obj}}
/freebsd/contrib/llvm-project/clang/lib/Headers/
H A D__clang_cuda_texture_intrinsics.h282 __device__ __rt __run<__dt>(cudaTextureObject_t __obj, __L(__args)) { \
284 asm(__asm_op : __L(__asm_outs) : "l"(__obj), __L(__asm_args)); \
322 __device__ static T __run(cudaTextureObject_t __obj, __L(__args)); \
332 __device__ static T __run(cudaTextureObject_t __obj, __L(__args)); \
344 __device__ static float4 __run(cudaTextureObject_t __obj, __L(__args)); \
535 __device__ static __T __run(cudaTextureObject_t __obj, float __x, float __y,
540 __obj, __x, __y, __comp);
543 __obj, __x, __y, __comp);
546 __obj, __x, __y, __comp);
549 __obj, __x, __y, __comp);
[all …]
/freebsd/contrib/llvm-project/libcxx/include/__utility/
H A Dexchange.h29 inline _LIBCPP_HIDE_FROM_ABI _LIBCPP_CONSTEXPR_SINCE_CXX20 _T1 exchange(_T1& __obj, _T2&& __new_val… in exchange() argument
31 _T1 __old_value = std::move(__obj); in exchange()
32 __obj = std::forward<_T2>(__new_value); in exchange()
/freebsd/contrib/llvm-project/libcxx/include/__atomic/
H A Datomic_ref.h227 _LIBCPP_HIDE_FROM_ABI __atomic_ref_base(_Tp& __obj) : __ptr_(std::addressof(__obj)) {}
246 _LIBCPP_HIDE_FROM_ABI explicit atomic_ref(_Tp& __obj) : __base(__obj) {
248 reinterpret_cast<uintptr_t>(std::addressof(__obj)) % __base::required_alignment == 0,
266 _LIBCPP_HIDE_FROM_ABI explicit atomic_ref(_Tp& __obj) : __base(__obj) {
268 reinterpret_cast<uintptr_t>(std::addressof(__obj)) % __base::required_alignment == 0,
312 _LIBCPP_HIDE_FROM_ABI explicit atomic_ref(_Tp& __obj) : __base(__obj) {
314 reinterpret_cast<uintptr_t>(std::addressof(__obj)) % __base::required_alignment == 0,
/freebsd/sys/conf/
H A Dkern.post.mk339 .for __obj in ${DEPENDOBJS:O:u}
341 _depfile= ${.OBJDIR}/${__obj}.meta
343 _depfile= ${.OBJDIR}/.depend.${__obj}
346 .if ${SYSTEM_OBJS:M${__obj}}
347 ${__obj}: ${OBJS_DEPEND_GUESS}
349 ${__obj}: ${OBJS_DEPEND_GUESS.${__obj}}
356 .if ${SYSTEM_OBJS:M${__obj}}
357 ${__obj}: ${OBJS_DEPEND_GUESS:N*.h}
359 ${__obj}: ${OBJS_DEPEND_GUESS.${__obj}}
/freebsd/contrib/llvm-project/libcxx/include/__flat_map/
H A Dflat_map.h665 insert_or_assign(const key_type& __key, _Mapped&& __obj) { in insert_or_assign() argument
666 return __insert_or_assign(__key, std::forward<_Mapped>(__obj)); in insert_or_assign()
672 insert_or_assign(key_type&& __key, _Mapped&& __obj) { in insert_or_assign() argument
673 return __insert_or_assign(std::move(__key), std::forward<_Mapped>(__obj)); in insert_or_assign()
680 insert_or_assign(_Kp&& __key, _Mapped&& __obj) { in insert_or_assign() argument
681 return __insert_or_assign(std::forward<_Kp>(__key), std::forward<_Mapped>(__obj)); in insert_or_assign()
687 insert_or_assign(const_iterator __hint, const key_type& __key, _Mapped&& __obj) { in insert_or_assign() argument
688 return __insert_or_assign(__hint, __key, std::forward<_Mapped>(__obj)); in insert_or_assign()
694 insert_or_assign(const_iterator __hint, key_type&& __key, _Mapped&& __obj) { in insert_or_assign() argument
695 return __insert_or_assign(__hint, std::move(__key), std::forward<_Mapped>(__obj)); in insert_or_assign()
[all …]